execnet: Rapid multi-Python deployment
======================================

Description
-----------

Rapid multi-Python deployment

License
-------

Upstream Contact
----------------

https://pypi.org/project/execnet/

